@@ -33,25 +33,29 @@ struct _PangoLayout
   /* If you add fields to PangoLayout, be sure to update both
    * the _copy function
    */
-  
+
   PangoContext *context;
   PangoAttrList *attrs;
   PangoFontDescription *font_desc;
-  
+
   gchar *text;
   int length;			/* length of text in bytes */
   int width;			/* wrap width, in device units */
   int indent;			/* amount by which first line should be shorter */
   int spacing;			/* spacing between lines */
 
+  int unknown_glyphs_count;	/* number of unknown glyphs */
+
   guint justify : 1;
   guint alignment : 2;
 
   guint single_paragraph : 1;
   guint auto_dir : 1;
-  
+
   guint wrap : 2;		/* PangoWrapMode */
+  guint is_wrapped : 1;		/* Whether the layout has any wrapped lines */
   guint ellipsize : 2;		/* PangoEllipsizeMode */
+  guint is_ellipsized : 1;	/* Whether the layout has any ellipsized lines */
 
   /* some caching */
   guint logical_rect_cached : 1;
@@ -66,13 +70,13 @@ struct _PangoLayout
   int tab_width;		/* Cached width of a tab. -1 == not yet calculated */
 
   PangoTabArray *tabs;
-  
+
   GSList *lines;
 };
 
 G_END_DECLS
 
-void _pango_layout_line_ellipsize (PangoLayoutLine *line,
+gboolean _pango_layout_line_ellipsize (PangoLayoutLine *line,
 				   PangoAttrList   *attrs);
 PangoLayoutLine* _pango_layout_iter_get_line_readonly (PangoLayoutIter *iter);
 
